@@ -1,8 +1,8 @@
 /*
 **  OSSP l2 - Flexible Logging
-**  Copyright (c) 2001-2003 Cable & Wireless Deutschland GmbH
-**  Copyright (c) 2001-2003 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2005 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2001-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2005 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of OSSP l2, a flexible logging library which
 **  can be found at http://www.ossp.org/pkg/lib/l2/.
@@ -73,7 +73,9 @@
         cu(value)
 
 /* some hard-coded sizes :-( */
-#define L2_MAX_MSGSIZE         4096
+#define L2_MAX_OUTSIZE          4098 /* this value is for compatiblity with previous versions of L2 */
+#define L2_MAX_MSGSIZE          L2_MAX_OUTSIZE - 2 /* leave room for CR/LF although OSSP/UNIX use LF only */
+#define L2_MSG_BUFSIZE          L2_MAX_OUTSIZE + 1 /* reserve space for convenient trailing NUL */
 #define L2_MAX_FORMATTERS       128
 #define L2_MAX_HANDLERS         128
 #define L2_BROKEN_TIMER          -1
@@ -112,7 +114,7 @@ struct l2_env_st {
     int                   interval;
     l2_formatter_entry_t  formatters[L2_MAX_FORMATTERS];
     l2_handler_t         *handlers[L2_MAX_HANDLERS];
-    char                  message[L2_MAX_MSGSIZE];
+    char                  message[L2_MSG_BUFSIZE];
     char                  szError[1024];
     char                  szErrorInfo[512];
     l2_result_t           rvErrorInfo;
